==> kubernetes-model-gatewayapi-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPRouteFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPRouteFluent<A extends HTTPRouteFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public HTTPRouteFluent.MetadataNested<A> withNewMetadata();
  public HTTPRouteFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public HTTPRouteFluent.MetadataNested<A> editMetadata();
  public HTTPRouteFluent.MetadataNested<A> editOrNewMetadata();
  public HTTPRouteFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPRouteSpec getSpec();
  public HTTPRouteSpec buildSpec();
  public A withSpec(HTTPRouteSpec spec);
  public Boolean hasSpec();
  public HTTPRouteFluent.SpecNested<A> withNewSpec();
  public HTTPRouteFluent.SpecNested<A> withNewSpecLike(HTTPRouteSpec item);
  public HTTPRouteFluent.SpecNested<A> editSpec();
  public HTTPRouteFluent.SpecNested<A> editOrNewSpec();
  public HTTPRouteFluent.SpecNested<A> editOrNewSpecLike(HTTPRouteSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPRouteStatus getStatus();
  public HTTPRouteStatus buildStatus();
  public A withStatus(HTTPRouteStatus status);
  public Boolean hasStatus();
  public HTTPRouteFluent.StatusNested<A> withNewStatus();
  public HTTPRouteFluent.StatusNested<A> withNewStatusLike(HTTPRouteStatus item);
  public HTTPRouteFluent.StatusNested<A> editStatus();
  public HTTPRouteFluent.StatusNested<A> editOrNewStatus();
  public HTTPRouteFluent.StatusNested<A> editOrNewStatusLike(HTTPRouteStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<HTTPRouteFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,HTTPRouteSpecFluent<HTTPRouteFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,HTTPRouteStatusFluent<HTTPRouteFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPRouteFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPRouteFluent<A extends HTTPRouteFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public HTTPRouteFluent.MetadataNested<A> withNewMetadata();
  public HTTPRouteFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public HTTPRouteFluent.MetadataNested<A> editMetadata();
  public HTTPRouteFluent.MetadataNested<A> editOrNewMetadata();
  public HTTPRouteFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPRouteSpec getSpec();
  public HTTPRouteSpec buildSpec();
  public A withSpec(HTTPRouteSpec spec);
  public Boolean hasSpec();
  public HTTPRouteFluent.SpecNested<A> withNewSpec();
  public HTTPRouteFluent.SpecNested<A> withNewSpecLike(HTTPRouteSpec item);
  public HTTPRouteFluent.SpecNested<A> editSpec();
  public HTTPRouteFluent.SpecNested<A> editOrNewSpec();
  public HTTPRouteFluent.SpecNested<A> editOrNewSpecLike(HTTPRouteSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPRouteStatus getStatus();
  public HTTPRouteStatus buildStatus();
  public A withStatus(HTTPRouteStatus status);
  public Boolean hasStatus();
  public HTTPRouteFluent.StatusNested<A> withNewStatus();
  public HTTPRouteFluent.StatusNested<A> withNewStatusLike(HTTPRouteStatus item);
  public HTTPRouteFluent.StatusNested<A> editStatus();
  public HTTPRouteFluent.StatusNested<A> editOrNewStatus();
  public HTTPRouteFluent.StatusNested<A> editOrNewStatusLike(HTTPRouteStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<HTTPRouteFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,HTTPRouteSpecFluent<HTTPRouteFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,HTTPRouteStatusFluent<HTTPRouteFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}
